import { useTranslation } from "next-i18next";

import Container from "components/services/widget/container";
import Block from "components/services/widget/block";
import useWidgetAPI from "utils/proxy/use-widget-api";

export default function Component({ service }) {
  const { t } = useTranslation();
  const { widget } = service;
  const { data, error } = useWidgetAPI(widget, "widget", {
      refreshInterval: 5000,
    }
  );

  if (error) {
    return <Container service={service} error={error} />;
  }

  if (!data) {
    return (
      <Container service={service}>
        <Block label="Stored Tracks" />
        <Block label="Distinct Artists" />
        <Block label="Total Lyrics Length" />
      </Container>
    );
  }

  return (
    <Container service={service}>
      <Block label="Stored Tracks" value={t("common.number", { value: data.storedRows })} />
      <Block label="Distinct Artists" value={t("common.number", { value: data.distinctArtists })} />
      <Block label="Total Lyrics Length" value={t("common.number", { value: data.lyricsLength })} />
    </Container>
  );
}
